@@ -2,12 +2,13 @@ GQuark  bd_dm_error_quark (void) {
         return g_quark_from_static_string ("g-bd-dm-error-quark");
 }
 
-static const gchar const * const dm_functions[] = {
+static const gchar* const dm_functions[] = {
     "bd_dm_is_tech_avail",
     "bd_dm_create_linear",
     "bd_dm_remove",
     "bd_dm_name_from_node",
     "bd_dm_node_from_name",
+    "bd_dm_get_subsystem_from_name",
     "bd_dm_map_exists",
     "bd_dm_get_member_raid_sets",
     "bd_dm_activate_raid_set",
@@ -15,24 +16,24 @@ static const gchar const * const dm_functions[] = {
     "bd_dm_get_raid_set_type",
     NULL};
 
-gchar const * const * get_dm_functions (void) {
+const gchar* const* get_dm_functions (void) {
     return dm_functions;
 }
 
-static const guint8 dm_num_functions = 10;
+static const guint8 dm_num_functions = 11;
 
 guint8 get_dm_num_functions (void) {
     return dm_num_functions;
 }
 
-gboolean  bd_dm_is_tech_avail_stub (BDDMTech tech, guint64 mode, GError **error) {
+static gboolean  bd_dm_is_tech_avail_stub (BDDMTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_dm_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_is_tech_avail) (BDDMTech tech, guint64 mode, GError **error) = bd_dm_is_tech_avail_stub;
+static gboolean  (*_bd_dm_is_tech_avail) (BDDMTech tech, guint64 mode, GError **error) = bd_dm_is_tech_avail_stub;
 
 /**
  * bd_dm_is_tech_avail:
@@ -48,14 +49,14 @@ gboolean  bd_dm_is_tech_avail (BDDMTech tech, guint64 mode, GError **error) {
 }
 
 
-gboolean  bd_dm_create_linear_stub (const gchar *map_name, const gchar *device, guint64 length, const gchar *uuid, GError **error) {
+static gboolean  bd_dm_create_linear_stub (const gchar *map_name, const gchar *device, guint64 length, const gchar *uuid, GError **error) {
     g_critical ("The function 'bd_dm_create_linear' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_create_linear' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_create_linear) (const gchar *map_name, const gchar *device, guint64 length, const gchar *uuid, GError **error) = bd_dm_create_linear_stub;
+static gboolean  (*_bd_dm_create_linear) (const gchar *map_name, const gchar *device, guint64 length, const gchar *uuid, GError **error) = bd_dm_create_linear_stub;
 
 /**
  * bd_dm_create_linear:
@@ -75,14 +76,14 @@ gboolean  bd_dm_create_linear (const gchar *map_name, const gchar *device, guint
 }
 
 
-gboolean  bd_dm_remove_stub (const gchar *map_name, GError **error) {
+static gboolean  bd_dm_remove_stub (const gchar *map_name, GError **error) {
     g_critical ("The function 'bd_dm_remove' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_remove' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_remove) (const gchar *map_name, GError **error) = bd_dm_remove_stub;
+static gboolean  (*_bd_dm_remove) (const gchar *map_name, GError **error) = bd_dm_remove_stub;
 
 /**
  * bd_dm_remove:
@@ -98,14 +99,14 @@ gboolean  bd_dm_remove (const gchar *map_name, GError **error) {
 }
 
 
-gchar* bd_dm_name_from_node_stub (const gchar *dm_node, GError **error) {
+static gchar* bd_dm_name_from_node_stub (const gchar *dm_node, GError **error) {
     g_critical ("The function 'bd_dm_name_from_node' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_name_from_node' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_dm_name_from_node) (const gchar *dm_node, GError **error) = bd_dm_name_from_node_stub;
+static gchar* (*_bd_dm_name_from_node) (const gchar *dm_node, GError **error) = bd_dm_name_from_node_stub;
 
 /**
  * bd_dm_name_from_node:
@@ -122,14 +123,14 @@ gchar* bd_dm_name_from_node (const gchar *dm_node, GError **error) {
 }
 
 
-gchar* bd_dm_node_from_name_stub (const gchar *map_name, GError **error) {
+static gchar* bd_dm_node_from_name_stub (const gchar *map_name, GError **error) {
     g_critical ("The function 'bd_dm_node_from_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_node_from_name' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_dm_node_from_name) (const gchar *map_name, GError **error) = bd_dm_node_from_name_stub;
+static gchar* (*_bd_dm_node_from_name) (const gchar *map_name, GError **error) = bd_dm_node_from_name_stub;
 
 /**
  * bd_dm_node_from_name:
@@ -146,14 +147,37 @@ gchar* bd_dm_node_from_name (const gchar *map_name, GError **error) {
 }
 
 
-gboolean  bd_dm_map_exists_stub (const gchar *map_name, gboolean live_only, gboolean active_only, GError **error) {
+static gchar* bd_dm_get_subsystem_from_name_stub (const gchar *device_name, GError **error) {
+    g_critical ("The function 'bd_dm_get_subsystem_from_name' called, but not implemented!");
+    g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
+                "The function 'bd_dm_get_subsystem_from_name' called, but not implemented!");
+    return NULL;
+}
+
+static gchar* (*_bd_dm_get_subsystem_from_name) (const gchar *device_name, GError **error) = bd_dm_get_subsystem_from_name_stub;
+
+/**
+ * bd_dm_get_subsystem_from_name:
+ * @device_name: name of the device
+ * @error: (out): place to store error (if any)
+ *
+ * Returns: subsystem of the given device
+ *
+ * Tech category: %BD_DM_TECH_MAP-%BD_DM_TECH_MODE_QUERY
+ */
+gchar* bd_dm_get_subsystem_from_name (const gchar *device_name, GError **error) {
+    return _bd_dm_get_subsystem_from_name (device_name, error);
+}
+
+
+static gboolean  bd_dm_map_exists_stub (const gchar *map_name, gboolean live_only, gboolean active_only, GError **error) {
     g_critical ("The function 'bd_dm_map_exists' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_map_exists' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_map_exists) (const gchar *map_name, gboolean live_only, gboolean active_only, GError **error) = bd_dm_map_exists_stub;
+static gboolean  (*_bd_dm_map_exists) (const gchar *map_name, gboolean live_only, gboolean active_only, GError **error) = bd_dm_map_exists_stub;
 
 /**
  * bd_dm_map_exists:
@@ -172,14 +196,14 @@ gboolean  bd_dm_map_exists (const gchar *map_name, gboolean live_only, gboolean
 }
 
 
-gchar** bd_dm_get_member_raid_sets_stub (const gchar *name, const gchar *uuid, gint major, gint minor, GError **error) {
+static gchar** bd_dm_get_member_raid_sets_stub (const gchar *name, const gchar *uuid, gint major, gint minor, GError **error) {
     g_critical ("The function 'bd_dm_get_member_raid_sets' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_get_member_raid_sets' called, but not implemented!");
     return NULL;
 }
 
-gchar** (*_bd_dm_get_member_raid_sets) (const gchar *name, const gchar *uuid, gint major, gint minor, GError **error) = bd_dm_get_member_raid_sets_stub;
+static gchar** (*_bd_dm_get_member_raid_sets) (const gchar *name, const gchar *uuid, gint major, gint minor, GError **error) = bd_dm_get_member_raid_sets_stub;
 
 /**
  * bd_dm_get_member_raid_sets:
@@ -201,14 +225,14 @@ gchar** bd_dm_get_member_raid_sets (const gchar *name, const gchar *uuid, gint m
 }
 
 
-gboolean  bd_dm_activate_raid_set_stub (const gchar *name, GError **error) {
+static gboolean  bd_dm_activate_raid_set_stub (const gchar *name, GError **error) {
     g_critical ("The function 'bd_dm_activate_raid_set' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_activate_raid_set' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_activate_raid_set) (const gchar *name, GError **error) = bd_dm_activate_raid_set_stub;
+static gboolean  (*_bd_dm_activate_raid_set) (const gchar *name, GError **error) = bd_dm_activate_raid_set_stub;
 
 /**
  * bd_dm_activate_raid_set:
@@ -217,21 +241,21 @@ gboolean  (*_bd_dm_activate_raid_set) (const gchar *name, GError **error) = bd_d
  *
  * Returns: whether the RAID set @name was successfully activate or not
  *
- * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_CREATE_ACTIVATE
+ * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_MODE_CREATE_ACTIVATE
  */
 gboolean  bd_dm_activate_raid_set (const gchar *name, GError **error) {
     return _bd_dm_activate_raid_set (name, error);
 }
 
 
-gboolean  bd_dm_deactivate_raid_set_stub (const gchar *name, GError **error) {
+static gboolean  bd_dm_deactivate_raid_set_stub (const gchar *name, GError **error) {
     g_critical ("The function 'bd_dm_deactivate_raid_set' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_deactivate_raid_set' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_dm_deactivate_raid_set) (const gchar *name, GError **error) = bd_dm_deactivate_raid_set_stub;
+static gboolean  (*_bd_dm_deactivate_raid_set) (const gchar *name, GError **error) = bd_dm_deactivate_raid_set_stub;
 
 /**
  * bd_dm_deactivate_raid_set:
@@ -240,21 +264,21 @@ gboolean  (*_bd_dm_deactivate_raid_set) (const gchar *name, GError **error) = bd
  *
  * Returns: whether the RAID set @name was successfully deactivate or not
  *
- * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_REMOVE_DEACTIVATE
+ * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_MODE_REMOVE_DEACTIVATE
  */
 gboolean  bd_dm_deactivate_raid_set (const gchar *name, GError **error) {
     return _bd_dm_deactivate_raid_set (name, error);
 }
 
 
-gchar* bd_dm_get_raid_set_type_stub (const gchar *name, GError **error) {
+static gchar* bd_dm_get_raid_set_type_stub (const gchar *name, GError **error) {
     g_critical ("The function 'bd_dm_get_raid_set_type' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_dm_get_raid_set_type' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_dm_get_raid_set_type) (const gchar *name, GError **error) = bd_dm_get_raid_set_type_stub;
+static gchar* (*_bd_dm_get_raid_set_type) (const gchar *name, GError **error) = bd_dm_get_raid_set_type_stub;
 
 /**
  * bd_dm_get_raid_set_type:
@@ -263,7 +287,7 @@ gchar* (*_bd_dm_get_raid_set_type) (const gchar *name, GError **error) = bd_dm_g
  *
  * Returns: string representation of the @name RAID set's type
  *
- * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_QUERY
+ * Tech category: %BD_DM_TECH_RAID-%BD_DM_TECH_MODE_QUERY
  */
 gchar* bd_dm_get_raid_set_type (const gchar *name, GError **error) {
     return _bd_dm_get_raid_set_type (name, error);
@@ -325,6 +349,11 @@ gpointer load_dm_from_plugin(const gchar *so_name) {
     if ((error = dlerror()) != NULL)
         g_warning("failed to load bd_dm_node_from_name: %s", error);
 
+    dlerror();
+    * (void**) (&_bd_dm_get_subsystem_from_name) = dlsym(handle, "bd_dm_get_subsystem_from_name");
+    if ((error = dlerror()) != NULL)
+        g_warning("failed to load bd_dm_get_subsystem_from_name: %s", error);
+
     dlerror();
     * (void**) (&_bd_dm_map_exists) = dlsym(handle, "bd_dm_map_exists");
     if ((error = dlerror()) != NULL)
@@ -362,6 +391,7 @@ gboolean unload_dm (gpointer handle) {
     _bd_dm_remove = bd_dm_remove_stub;
     _bd_dm_name_from_node = bd_dm_name_from_node_stub;
     _bd_dm_node_from_name = bd_dm_node_from_name_stub;
+    _bd_dm_get_subsystem_from_name = bd_dm_get_subsystem_from_name_stub;
     _bd_dm_map_exists = bd_dm_map_exists_stub;
     _bd_dm_get_member_raid_sets = bd_dm_get_member_raid_sets_stub;
     _bd_dm_activate_raid_set = bd_dm_activate_raid_set_stub;
