@@ -14,7 +14,10 @@ GQuark  bd_kbd_error_quark (void) {
  * Creates a new copy of @data.
  */
 BDKBDZramStats* bd_kbd_zram_stats_copy (BDKBDZramStats *data) {
-        BDKBDZramStats *new = g_new0 (BDKBDZramStats, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDKBDZramStats *new = g_new0 (BDKBDZramStats, 1);
     new->disksize = data->disksize;
     new->num_reads = data->num_reads;
     new->num_writes = data->num_writes;
@@ -35,7 +38,10 @@ BDKBDZramStats* bd_kbd_zram_stats_copy (BDKBDZramStats *data) {
  * Frees @data.
  */
 void  bd_kbd_zram_stats_free (BDKBDZramStats *data) {
-        g_free (data->comp_algorithm);
+        if (data == NULL)
+        return;
+
+    g_free (data->comp_algorithm);
     g_free (data);
 }
 
@@ -68,7 +74,10 @@ GType  bd_kbd_zram_stats_get_type () {
  * Creates a new copy of @data.
  */
 BDKBDBcacheStats* bd_kbd_bcache_stats_copy (BDKBDBcacheStats *data) {
-        BDKBDBcacheStats *new = g_new0 (BDKBDBcacheStats, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDKBDBcacheStats *new = g_new0 (BDKBDBcacheStats, 1);
 
     new->state = g_strdup (data->state);
     new->block_size = data->block_size;
@@ -88,7 +97,10 @@ BDKBDBcacheStats* bd_kbd_bcache_stats_copy (BDKBDBcacheStats *data) {
  * Frees @data.
  */
 void  bd_kbd_bcache_stats_free (BDKBDBcacheStats *data) {
-        g_free (data->state);
+        if (data == NULL)
+        return;
+
+    g_free (data->state);
     g_free (data);
 }
 
@@ -104,7 +116,7 @@ GType  bd_kbd_bcache_stats_get_type () {
     return type;
 }
 
-static const gchar const * const kbd_functions[] = {
+static const gchar* const kbd_functions[] = {
     "bd_kbd_is_tech_avail",
     "bd_kbd_zram_create_devices",
     "bd_kbd_zram_destroy_devices",
@@ -124,7 +136,7 @@ static const gchar const * const kbd_functions[] = {
     "bd_kbd_bcache_get_cache_device",
     NULL};
 
-gchar const * const * get_kbd_functions (void) {
+const gchar* const* get_kbd_functions (void) {
     return kbd_functions;
 }
 
@@ -134,14 +146,14 @@ guint8 get_kbd_num_functions (void) {
     return kbd_num_functions;
 }
 
-gboolean  bd_kbd_is_tech_avail_stub (BDKBDTech tech, guint64 mode, GError **error) {
+static gboolean  bd_kbd_is_tech_avail_stub (BDKBDTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_kbd_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_is_tech_avail) (BDKBDTech tech, guint64 mode, GError **error) = bd_kbd_is_tech_avail_stub;
+static gboolean  (*_bd_kbd_is_tech_avail) (BDKBDTech tech, guint64 mode, GError **error) = bd_kbd_is_tech_avail_stub;
 
 /**
  * bd_kbd_is_tech_avail:
@@ -157,14 +169,14 @@ gboolean  bd_kbd_is_tech_avail (BDKBDTech tech, guint64 mode, GError **error) {
 }
 
 
-gboolean  bd_kbd_zram_create_devices_stub (guint64 num_devices, const guint64 *sizes, const guint64 *nstreams, GError **error) {
+static gboolean  bd_kbd_zram_create_devices_stub (guint64 num_devices, const guint64 *sizes, const guint64 *nstreams, GError **error) {
     g_critical ("The function 'bd_kbd_zram_create_devices' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_zram_create_devices' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_zram_create_devices) (guint64 num_devices, const guint64 *sizes, const guint64 *nstreams, GError **error) = bd_kbd_zram_create_devices_stub;
+static gboolean  (*_bd_kbd_zram_create_devices) (guint64 num_devices, const guint64 *sizes, const guint64 *nstreams, GError **error) = bd_kbd_zram_create_devices_stub;
 
 /**
  * bd_kbd_zram_create_devices:
@@ -186,14 +198,14 @@ gboolean  bd_kbd_zram_create_devices (guint64 num_devices, const guint64 *sizes,
 }
 
 
-gboolean  bd_kbd_zram_destroy_devices_stub (GError **error) {
+static gboolean  bd_kbd_zram_destroy_devices_stub (GError **error) {
     g_critical ("The function 'bd_kbd_zram_destroy_devices' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_zram_destroy_devices' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_zram_destroy_devices) (GError **error) = bd_kbd_zram_destroy_devices_stub;
+static gboolean  (*_bd_kbd_zram_destroy_devices) (GError **error) = bd_kbd_zram_destroy_devices_stub;
 
 /**
  * bd_kbd_zram_destroy_devices:
@@ -212,14 +224,14 @@ gboolean  bd_kbd_zram_destroy_devices (GError **error) {
 }
 
 
-gboolean  bd_kbd_zram_add_device_stub (guint64 size, guint64 nstreams, gchar **device, GError **error) {
+static gboolean  bd_kbd_zram_add_device_stub (guint64 size, guint64 nstreams, gchar **device, GError **error) {
     g_critical ("The function 'bd_kbd_zram_add_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_zram_add_device' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_zram_add_device) (guint64 size, guint64 nstreams, gchar **device, GError **error) = bd_kbd_zram_add_device_stub;
+static gboolean  (*_bd_kbd_zram_add_device) (guint64 size, guint64 nstreams, gchar **device, GError **error) = bd_kbd_zram_add_device_stub;
 
 /**
  * bd_kbd_zram_add_device:
@@ -237,14 +249,14 @@ gboolean  bd_kbd_zram_add_device (guint64 size, guint64 nstreams, gchar **device
 }
 
 
-gboolean  bd_kbd_zram_remove_device_stub (const gchar *device, GError **error) {
+static gboolean  bd_kbd_zram_remove_device_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_kbd_zram_remove_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_zram_remove_device' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_zram_remove_device) (const gchar *device, GError **error) = bd_kbd_zram_remove_device_stub;
+static gboolean  (*_bd_kbd_zram_remove_device) (const gchar *device, GError **error) = bd_kbd_zram_remove_device_stub;
 
 /**
  * bd_kbd_zram_remove_device:
@@ -260,14 +272,14 @@ gboolean  bd_kbd_zram_remove_device (const gchar *device, GError **error) {
 }
 
 
-BDKBDZramStats* bd_kbd_zram_get_stats_stub (const gchar *device, GError **error) {
+static BDKBDZramStats* bd_kbd_zram_get_stats_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_kbd_zram_get_stats' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_zram_get_stats' called, but not implemented!");
     return NULL;
 }
 
-BDKBDZramStats* (*_bd_kbd_zram_get_stats) (const gchar *device, GError **error) = bd_kbd_zram_get_stats_stub;
+static BDKBDZramStats* (*_bd_kbd_zram_get_stats) (const gchar *device, GError **error) = bd_kbd_zram_get_stats_stub;
 
 /**
  * bd_kbd_zram_get_stats:
@@ -283,14 +295,14 @@ BDKBDZramStats* bd_kbd_zram_get_stats (const gchar *device, GError **error) {
 }
 
 
-gboolean  bd_kbd_bcache_create_stub (const gchar *backing_device, const gchar *cache_device, const BDExtraArg **extra, const gchar **bcache_device, GError **error) {
+static gboolean  bd_kbd_bcache_create_stub (const gchar *backing_device, const gchar *cache_device, const BDExtraArg **extra, const gchar **bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_create' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_create' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_bcache_create) (const gchar *backing_device, const gchar *cache_device, const BDExtraArg **extra, const gchar **bcache_device, GError **error) = bd_kbd_bcache_create_stub;
+static gboolean  (*_bd_kbd_bcache_create) (const gchar *backing_device, const gchar *cache_device, const BDExtraArg **extra, const gchar **bcache_device, GError **error) = bd_kbd_bcache_create_stub;
 
 /**
  * bd_kbd_bcache_create:
@@ -310,14 +322,14 @@ gboolean  bd_kbd_bcache_create (const gchar *backing_device, const gchar *cache_
 }
 
 
-gboolean  bd_kbd_bcache_attach_stub (const gchar *c_set_uuid, const gchar *bcache_device, GError **error) {
+static gboolean  bd_kbd_bcache_attach_stub (const gchar *c_set_uuid, const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_attach' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_attach' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_bcache_attach) (const gchar *c_set_uuid, const gchar *bcache_device, GError **error) = bd_kbd_bcache_attach_stub;
+static gboolean  (*_bd_kbd_bcache_attach) (const gchar *c_set_uuid, const gchar *bcache_device, GError **error) = bd_kbd_bcache_attach_stub;
 
 /**
  * bd_kbd_bcache_attach:
@@ -334,14 +346,14 @@ gboolean  bd_kbd_bcache_attach (const gchar *c_set_uuid, const gchar *bcache_dev
 }
 
 
-gboolean  bd_kbd_bcache_detach_stub (const gchar *bcache_device, gchar **c_set_uuid, GError **error) {
+static gboolean  bd_kbd_bcache_detach_stub (const gchar *bcache_device, gchar **c_set_uuid, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_detach' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_detach' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_bcache_detach) (const gchar *bcache_device, gchar **c_set_uuid, GError **error) = bd_kbd_bcache_detach_stub;
+static gboolean  (*_bd_kbd_bcache_detach) (const gchar *bcache_device, gchar **c_set_uuid, GError **error) = bd_kbd_bcache_detach_stub;
 
 /**
  * bd_kbd_bcache_detach:
@@ -359,14 +371,14 @@ gboolean  bd_kbd_bcache_detach (const gchar *bcache_device, gchar **c_set_uuid,
 }
 
 
-gboolean  bd_kbd_bcache_destroy_stub (const gchar *bcache_device, GError **error) {
+static gboolean  bd_kbd_bcache_destroy_stub (const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_destroy' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_destroy' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_bcache_destroy) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_destroy_stub;
+static gboolean  (*_bd_kbd_bcache_destroy) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_destroy_stub;
 
 /**
  * bd_kbd_bcache_destroy:
@@ -382,14 +394,14 @@ gboolean  bd_kbd_bcache_destroy (const gchar *bcache_device, GError **error) {
 }
 
 
-BDKBDBcacheMode  bd_kbd_bcache_get_mode_stub (const gchar *bcache_device, GError **error) {
+static BDKBDBcacheMode  bd_kbd_bcache_get_mode_stub (const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_get_mode' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_get_mode' called, but not implemented!");
     return 0;
 }
 
-BDKBDBcacheMode  (*_bd_kbd_bcache_get_mode) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_mode_stub;
+static BDKBDBcacheMode  (*_bd_kbd_bcache_get_mode) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_mode_stub;
 
 /**
  * bd_kbd_bcache_get_mode:
@@ -405,14 +417,14 @@ BDKBDBcacheMode  bd_kbd_bcache_get_mode (const gchar *bcache_device, GError **er
 }
 
 
-const gchar* bd_kbd_bcache_get_mode_str_stub (BDKBDBcacheMode mode, GError **error) {
+static const gchar* bd_kbd_bcache_get_mode_str_stub (BDKBDBcacheMode mode, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_get_mode_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_get_mode_str' called, but not implemented!");
     return NULL;
 }
 
-const gchar* (*_bd_kbd_bcache_get_mode_str) (BDKBDBcacheMode mode, GError **error) = bd_kbd_bcache_get_mode_str_stub;
+static const gchar* (*_bd_kbd_bcache_get_mode_str) (BDKBDBcacheMode mode, GError **error) = bd_kbd_bcache_get_mode_str_stub;
 
 /**
  * bd_kbd_bcache_get_mode_str:
@@ -428,14 +440,14 @@ const gchar* bd_kbd_bcache_get_mode_str (BDKBDBcacheMode mode, GError **error) {
 }
 
 
-BDKBDBcacheMode  bd_kbd_bcache_get_mode_from_str_stub (const gchar *mode_str, GError **error) {
+static BDKBDBcacheMode  bd_kbd_bcache_get_mode_from_str_stub (const gchar *mode_str, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_get_mode_from_str' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_get_mode_from_str' called, but not implemented!");
     return 0;
 }
 
-BDKBDBcacheMode  (*_bd_kbd_bcache_get_mode_from_str) (const gchar *mode_str, GError **error) = bd_kbd_bcache_get_mode_from_str_stub;
+static BDKBDBcacheMode  (*_bd_kbd_bcache_get_mode_from_str) (const gchar *mode_str, GError **error) = bd_kbd_bcache_get_mode_from_str_stub;
 
 /**
  * bd_kbd_bcache_get_mode_from_str:
@@ -449,14 +461,14 @@ BDKBDBcacheMode  bd_kbd_bcache_get_mode_from_str (const gchar *mode_str, GError
 }
 
 
-gboolean  bd_kbd_bcache_set_mode_stub (const gchar *bcache_device, BDKBDBcacheMode mode, GError **error) {
+static gboolean  bd_kbd_bcache_set_mode_stub (const gchar *bcache_device, BDKBDBcacheMode mode, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_set_mode' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_set_mode' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_kbd_bcache_set_mode) (const gchar *bcache_device, BDKBDBcacheMode mode, GError **error) = bd_kbd_bcache_set_mode_stub;
+static gboolean  (*_bd_kbd_bcache_set_mode) (const gchar *bcache_device, BDKBDBcacheMode mode, GError **error) = bd_kbd_bcache_set_mode_stub;
 
 /**
  * bd_kbd_bcache_set_mode:
@@ -473,14 +485,14 @@ gboolean  bd_kbd_bcache_set_mode (const gchar *bcache_device, BDKBDBcacheMode mo
 }
 
 
-BDKBDBcacheStats* bd_kbd_bcache_status_stub (const gchar *bcache_device, GError **error) {
+static BDKBDBcacheStats* bd_kbd_bcache_status_stub (const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_status' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_status' called, but not implemented!");
     return NULL;
 }
 
-BDKBDBcacheStats* (*_bd_kbd_bcache_status) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_status_stub;
+static BDKBDBcacheStats* (*_bd_kbd_bcache_status) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_status_stub;
 
 /**
  * bd_kbd_bcache_status:
@@ -497,14 +509,14 @@ BDKBDBcacheStats* bd_kbd_bcache_status (const gchar *bcache_device, GError **err
 }
 
 
-gchar* bd_kbd_bcache_get_backing_device_stub (const gchar *bcache_device, GError **error) {
+static gchar* bd_kbd_bcache_get_backing_device_stub (const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_get_backing_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_get_backing_device' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_kbd_bcache_get_backing_device) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_backing_device_stub;
+static gchar* (*_bd_kbd_bcache_get_backing_device) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_backing_device_stub;
 
 /**
  * bd_kbd_bcache_get_backing_device:
@@ -521,14 +533,14 @@ gchar* bd_kbd_bcache_get_backing_device (const gchar *bcache_device, GError **er
 }
 
 
-gchar* bd_kbd_bcache_get_cache_device_stub (const gchar *bcache_device, GError **error) {
+static gchar* bd_kbd_bcache_get_cache_device_stub (const gchar *bcache_device, GError **error) {
     g_critical ("The function 'bd_kbd_bcache_get_cache_device' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_kbd_bcache_get_cache_device' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_kbd_bcache_get_cache_device) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_cache_device_stub;
+static gchar* (*_bd_kbd_bcache_get_cache_device) (const gchar *bcache_device, GError **error) = bd_kbd_bcache_get_cache_device_stub;
 
 /**
  * bd_kbd_bcache_get_cache_device:
