@@ -22,7 +22,10 @@ GQuark  bd_md_error_quark (void) {
  * Creates a new copy of @data.
  */
 BDMDExamineData* bd_md_examine_data_copy (BDMDExamineData *data) {
-        BDMDExamineData *new_data = g_new0 (BDMDExamineData, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDMDExamineData *new_data = g_new0 (BDMDExamineData, 1);
 
     new_data->device = g_strdup (data->device);
     new_data->level = g_strdup (data->level);
@@ -44,7 +47,10 @@ BDMDExamineData* bd_md_examine_data_copy (BDMDExamineData *data) {
  * Frees @data.
  */
 void  bd_md_examine_data_free (BDMDExamineData *data) {
-        g_free (data->device);
+        if (data == NULL)
+        return;
+
+    g_free (data->device);
     g_free (data->level);
     g_free (data->name);
     g_free (data->uuid);
@@ -89,7 +95,10 @@ GType  bd_md_examine_data_get_type () {
  * Creates a new copy of @data.
  */
 BDMDDetailData* bd_md_detail_data_copy (BDMDDetailData *data) {
-        BDMDDetailData *new_data = g_new0 (BDMDDetailData, 1);
+        if (data == NULL)
+        return NULL;
+
+    BDMDDetailData *new_data = g_new0 (BDMDDetailData, 1);
 
     new_data->device = g_strdup (data->device);
     new_data->name = g_strdup (data->name);
@@ -115,7 +124,10 @@ BDMDDetailData* bd_md_detail_data_copy (BDMDDetailData *data) {
  * Frees @data.
  */
 void  bd_md_detail_data_free (BDMDDetailData *data) {
-        g_free (data->device);
+        if (data == NULL)
+        return;
+
+    g_free (data->device);
     g_free (data->name);
     g_free (data->metadata);
     g_free (data->creation_time);
@@ -137,7 +149,7 @@ GType  bd_md_detail_data_get_type () {
     return type;
 }
 
-static const gchar const * const mdraid_functions[] = {
+static const gchar* const mdraid_functions[] = {
     "bd_md_is_tech_avail",
     "bd_md_get_superblock_size",
     "bd_md_create",
@@ -161,7 +173,7 @@ static const gchar const * const mdraid_functions[] = {
     "bd_md_request_sync_action",
     NULL};
 
-gchar const * const * get_mdraid_functions (void) {
+const gchar* const* get_mdraid_functions (void) {
     return mdraid_functions;
 }
 
@@ -171,14 +183,14 @@ guint8 get_mdraid_num_functions (void) {
     return mdraid_num_functions;
 }
 
-gboolean  bd_md_is_tech_avail_stub (BDMDTech tech, guint64 mode, GError **error) {
+static gboolean  bd_md_is_tech_avail_stub (BDMDTech tech, guint64 mode, GError **error) {
     g_critical ("The function 'bd_md_is_tech_avail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_is_tech_avail' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_is_tech_avail) (BDMDTech tech, guint64 mode, GError **error) = bd_md_is_tech_avail_stub;
+static gboolean  (*_bd_md_is_tech_avail) (BDMDTech tech, guint64 mode, GError **error) = bd_md_is_tech_avail_stub;
 
 /**
  * bd_md_is_tech_avail:
@@ -194,14 +206,14 @@ gboolean  bd_md_is_tech_avail (BDMDTech tech, guint64 mode, GError **error) {
 }
 
 
-guint64  bd_md_get_superblock_size_stub (guint64 member_size, const gchar *version, GError **error) {
+static guint64  bd_md_get_superblock_size_stub (guint64 member_size, const gchar *version, GError **error) {
     g_critical ("The function 'bd_md_get_superblock_size' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_superblock_size' called, but not implemented!");
     return 0;
 }
 
-guint64  (*_bd_md_get_superblock_size) (guint64 member_size, const gchar *version, GError **error) = bd_md_get_superblock_size_stub;
+static guint64  (*_bd_md_get_superblock_size) (guint64 member_size, const gchar *version, GError **error) = bd_md_get_superblock_size_stub;
 
 /**
  * bd_md_get_superblock_size:
@@ -219,14 +231,14 @@ guint64  bd_md_get_superblock_size (guint64 member_size, const gchar *version, G
 }
 
 
-gboolean  bd_md_create_stub (const gchar *device_name, const gchar *level, const gchar **disks, guint64 spares, const gchar *version, gboolean bitmap, guint64 chunk_size, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_create_stub (const gchar *device_name, const gchar *level, const gchar **disks, guint64 spares, const gchar *version, gboolean bitmap, guint64 chunk_size, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_md_create' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_create' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_create) (const gchar *device_name, const gchar *level, const gchar **disks, guint64 spares, const gchar *version, gboolean bitmap, guint64 chunk_size, const BDExtraArg **extra, GError **error) = bd_md_create_stub;
+static gboolean  (*_bd_md_create) (const gchar *device_name, const gchar *level, const gchar **disks, guint64 spares, const gchar *version, gboolean bitmap, guint64 chunk_size, const BDExtraArg **extra, GError **error) = bd_md_create_stub;
 
 /**
  * bd_md_create:
@@ -250,14 +262,14 @@ gboolean  bd_md_create (const gchar *device_name, const gchar *level, const gcha
 }
 
 
-gboolean  bd_md_destroy_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_destroy_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_md_destroy' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_destroy' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_destroy) (const gchar *device, GError **error) = bd_md_destroy_stub;
+static gboolean  (*_bd_md_destroy) (const gchar *device, GError **error) = bd_md_destroy_stub;
 
 /**
  * bd_md_destroy:
@@ -273,14 +285,14 @@ gboolean  bd_md_destroy (const gchar *device, GError **error) {
 }
 
 
-gboolean  bd_md_deactivate_stub (const gchar *raid_spec, GError **error) {
+static gboolean  bd_md_deactivate_stub (const gchar *raid_spec, GError **error) {
     g_critical ("The function 'bd_md_deactivate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_deactivate' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_deactivate) (const gchar *raid_spec, GError **error) = bd_md_deactivate_stub;
+static gboolean  (*_bd_md_deactivate) (const gchar *raid_spec, GError **error) = bd_md_deactivate_stub;
 
 /**
  * bd_md_deactivate:
@@ -296,14 +308,14 @@ gboolean  bd_md_deactivate (const gchar *raid_spec, GError **error) {
 }
 
 
-gboolean  bd_md_activate_stub (const gchar *raid_spec, const gchar **members, const gchar *uuid, gboolean start_degraded, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_activate_stub (const gchar *raid_spec, const gchar **members, const gchar *uuid, gboolean start_degraded, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_md_activate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_activate' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_activate) (const gchar *raid_spec, const gchar **members, const gchar *uuid, gboolean start_degraded, const BDExtraArg **extra, GError **error) = bd_md_activate_stub;
+static gboolean  (*_bd_md_activate) (const gchar *raid_spec, const gchar **members, const gchar *uuid, gboolean start_degraded, const BDExtraArg **extra, GError **error) = bd_md_activate_stub;
 
 /**
  * bd_md_activate:
@@ -326,14 +338,14 @@ gboolean  bd_md_activate (const gchar *raid_spec, const gchar **members, const g
 }
 
 
-gboolean  bd_md_run_stub (const gchar *raid_spec, GError **error) {
+static gboolean  bd_md_run_stub (const gchar *raid_spec, GError **error) {
     g_critical ("The function 'bd_md_run' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_run' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_run) (const gchar *raid_spec, GError **error) = bd_md_run_stub;
+static gboolean  (*_bd_md_run) (const gchar *raid_spec, GError **error) = bd_md_run_stub;
 
 /**
  * bd_md_run:
@@ -349,14 +361,14 @@ gboolean  bd_md_run (const gchar *raid_spec, GError **error) {
 }
 
 
-gboolean  bd_md_nominate_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_nominate_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_md_nominate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_nominate' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_nominate) (const gchar *device, GError **error) = bd_md_nominate_stub;
+static gboolean  (*_bd_md_nominate) (const gchar *device, GError **error) = bd_md_nominate_stub;
 
 /**
  * bd_md_nominate:
@@ -375,14 +387,14 @@ gboolean  bd_md_nominate (const gchar *device, GError **error) {
 }
 
 
-gboolean  bd_md_denominate_stub (const gchar *device, GError **error) {
+static gboolean  bd_md_denominate_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_md_denominate' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_denominate' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_denominate) (const gchar *device, GError **error) = bd_md_denominate_stub;
+static gboolean  (*_bd_md_denominate) (const gchar *device, GError **error) = bd_md_denominate_stub;
 
 /**
  * bd_md_denominate:
@@ -401,14 +413,14 @@ gboolean  bd_md_denominate (const gchar *device, GError **error) {
 }
 
 
-gboolean  bd_md_add_stub (const gchar *raid_spec, const gchar *device, guint64 raid_devs, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_add_stub (const gchar *raid_spec, const gchar *device, guint64 raid_devs, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_md_add' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_add' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_add) (const gchar *raid_spec, const gchar *device, guint64 raid_devs, const BDExtraArg **extra, GError **error) = bd_md_add_stub;
+static gboolean  (*_bd_md_add) (const gchar *raid_spec, const gchar *device, guint64 raid_devs, const BDExtraArg **extra, GError **error) = bd_md_add_stub;
 
 /**
  * bd_md_add:
@@ -437,14 +449,14 @@ gboolean  bd_md_add (const gchar *raid_spec, const gchar *device, guint64 raid_d
 }
 
 
-gboolean  bd_md_remove_stub (const gchar *raid_spec, const gchar *device, gboolean fail, const BDExtraArg **extra, GError **error) {
+static gboolean  bd_md_remove_stub (const gchar *raid_spec, const gchar *device, gboolean fail, const BDExtraArg **extra, GError **error) {
     g_critical ("The function 'bd_md_remove' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_remove' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_remove) (const gchar *raid_spec, const gchar *device, gboolean fail, const BDExtraArg **extra, GError **error) = bd_md_remove_stub;
+static gboolean  (*_bd_md_remove) (const gchar *raid_spec, const gchar *device, gboolean fail, const BDExtraArg **extra, GError **error) = bd_md_remove_stub;
 
 /**
  * bd_md_remove:
@@ -465,14 +477,14 @@ gboolean  bd_md_remove (const gchar *raid_spec, const gchar *device, gboolean fa
 }
 
 
-BDMDExamineData* bd_md_examine_stub (const gchar *device, GError **error) {
+static BDMDExamineData* bd_md_examine_stub (const gchar *device, GError **error) {
     g_critical ("The function 'bd_md_examine' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_examine' called, but not implemented!");
     return NULL;
 }
 
-BDMDExamineData* (*_bd_md_examine) (const gchar *device, GError **error) = bd_md_examine_stub;
+static BDMDExamineData* (*_bd_md_examine) (const gchar *device, GError **error) = bd_md_examine_stub;
 
 /**
  * bd_md_examine:
@@ -488,14 +500,14 @@ BDMDExamineData* bd_md_examine (const gchar *device, GError **error) {
 }
 
 
-BDMDDetailData* bd_md_detail_stub (const gchar *raid_spec, GError **error) {
+static BDMDDetailData* bd_md_detail_stub (const gchar *raid_spec, GError **error) {
     g_critical ("The function 'bd_md_detail' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_detail' called, but not implemented!");
     return NULL;
 }
 
-BDMDDetailData* (*_bd_md_detail) (const gchar *raid_spec, GError **error) = bd_md_detail_stub;
+static BDMDDetailData* (*_bd_md_detail) (const gchar *raid_spec, GError **error) = bd_md_detail_stub;
 
 /**
  * bd_md_detail:
@@ -511,14 +523,14 @@ BDMDDetailData* bd_md_detail (const gchar *raid_spec, GError **error) {
 }
 
 
-gchar* bd_md_canonicalize_uuid_stub (const gchar *uuid, GError **error) {
+static gchar* bd_md_canonicalize_uuid_stub (const gchar *uuid, GError **error) {
     g_critical ("The function 'bd_md_canonicalize_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_canonicalize_uuid' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_canonicalize_uuid) (const gchar *uuid, GError **error) = bd_md_canonicalize_uuid_stub;
+static gchar* (*_bd_md_canonicalize_uuid) (const gchar *uuid, GError **error) = bd_md_canonicalize_uuid_stub;
 
 /**
  * bd_md_canonicalize_uuid:
@@ -537,14 +549,14 @@ gchar* bd_md_canonicalize_uuid (const gchar *uuid, GError **error) {
 }
 
 
-gchar* bd_md_get_md_uuid_stub (const gchar *uuid, GError **error) {
+static gchar* bd_md_get_md_uuid_stub (const gchar *uuid, GError **error) {
     g_critical ("The function 'bd_md_get_md_uuid' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_md_uuid' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_get_md_uuid) (const gchar *uuid, GError **error) = bd_md_get_md_uuid_stub;
+static gchar* (*_bd_md_get_md_uuid) (const gchar *uuid, GError **error) = bd_md_get_md_uuid_stub;
 
 /**
  * bd_md_get_md_uuid:
@@ -565,14 +577,14 @@ gchar* bd_md_get_md_uuid (const gchar *uuid, GError **error) {
 }
 
 
-gchar* bd_md_node_from_name_stub (const gchar *name, GError **error) {
+static gchar* bd_md_node_from_name_stub (const gchar *name, GError **error) {
     g_critical ("The function 'bd_md_node_from_name' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_node_from_name' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_node_from_name) (const gchar *name, GError **error) = bd_md_node_from_name_stub;
+static gchar* (*_bd_md_node_from_name) (const gchar *name, GError **error) = bd_md_node_from_name_stub;
 
 /**
  * bd_md_node_from_name:
@@ -588,14 +600,14 @@ gchar* bd_md_node_from_name (const gchar *name, GError **error) {
 }
 
 
-gchar* bd_md_name_from_node_stub (const gchar *node, GError **error) {
+static gchar* bd_md_name_from_node_stub (const gchar *node, GError **error) {
     g_critical ("The function 'bd_md_name_from_node' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_name_from_node' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_name_from_node) (const gchar *node, GError **error) = bd_md_name_from_node_stub;
+static gchar* (*_bd_md_name_from_node) (const gchar *node, GError **error) = bd_md_name_from_node_stub;
 
 /**
  * bd_md_name_from_node:
@@ -611,14 +623,14 @@ gchar* bd_md_name_from_node (const gchar *node, GError **error) {
 }
 
 
-gchar* bd_md_get_status_stub (const gchar *raid_spec, GError **error) {
+static gchar* bd_md_get_status_stub (const gchar *raid_spec, GError **error) {
     g_critical ("The function 'bd_md_get_status' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_status' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_get_status) (const gchar *raid_spec, GError **error) = bd_md_get_status_stub;
+static gchar* (*_bd_md_get_status) (const gchar *raid_spec, GError **error) = bd_md_get_status_stub;
 
 /**
  * bd_md_get_status
@@ -634,14 +646,14 @@ gchar* bd_md_get_status (const gchar *raid_spec, GError **error) {
 }
 
 
-gboolean  bd_md_set_bitmap_location_stub (const gchar *raid_spec, const gchar *location, GError **error) {
+static gboolean  bd_md_set_bitmap_location_stub (const gchar *raid_spec, const gchar *location, GError **error) {
     g_critical ("The function 'bd_md_set_bitmap_location' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_set_bitmap_location' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_set_bitmap_location) (const gchar *raid_spec, const gchar *location, GError **error) = bd_md_set_bitmap_location_stub;
+static gboolean  (*_bd_md_set_bitmap_location) (const gchar *raid_spec, const gchar *location, GError **error) = bd_md_set_bitmap_location_stub;
 
 /**
  * bd_md_set_bitmap_location:
@@ -658,14 +670,14 @@ gboolean  bd_md_set_bitmap_location (const gchar *raid_spec, const gchar *locati
 }
 
 
-gchar* bd_md_get_bitmap_location_stub (const gchar *raid_spec, GError **error) {
+static gchar* bd_md_get_bitmap_location_stub (const gchar *raid_spec, GError **error) {
     g_critical ("The function 'bd_md_get_bitmap_location' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_get_bitmap_location' called, but not implemented!");
     return NULL;
 }
 
-gchar* (*_bd_md_get_bitmap_location) (const gchar *raid_spec, GError **error) = bd_md_get_bitmap_location_stub;
+static gchar* (*_bd_md_get_bitmap_location) (const gchar *raid_spec, GError **error) = bd_md_get_bitmap_location_stub;
 
 /**
  * bd_md_get_bitmap_location:
@@ -681,14 +693,14 @@ gchar* bd_md_get_bitmap_location (const gchar *raid_spec, GError **error) {
 }
 
 
-gboolean  bd_md_request_sync_action_stub (const gchar *raid_spec, const gchar *action, GError **error) {
+static gboolean  bd_md_request_sync_action_stub (const gchar *raid_spec, const gchar *action, GError **error) {
     g_critical ("The function 'bd_md_request_sync_action' called, but not implemented!");
     g_set_error (error, BD_INIT_ERROR, BD_INIT_ERROR_NOT_IMPLEMENTED,
                 "The function 'bd_md_request_sync_action' called, but not implemented!");
     return FALSE;
 }
 
-gboolean  (*_bd_md_request_sync_action) (const gchar *raid_spec, const gchar *action, GError **error) = bd_md_request_sync_action_stub;
+static gboolean  (*_bd_md_request_sync_action) (const gchar *raid_spec, const gchar *action, GError **error) = bd_md_request_sync_action_stub;
 
 /**
  * bd_md_request_sync_action:
