@@ -250,6 +250,9 @@ static void crypto_log_redirect (gint level, const gchar *msg, void *usrptr __at
  *
  */
 gboolean bd_crypto_init (void) {
+#ifdef DEBUG
+    crypt_set_debug_level (CRYPT_DEBUG_ALL);
+#endif
     c_locale = newlocale (LC_ALL_MASK, "C", c_locale);
     crypt_set_log_callback (NULL, &crypto_log_redirect, NULL);
     return TRUE;
@@ -265,6 +268,7 @@ gboolean bd_crypto_init (void) {
 void bd_crypto_close (void) {
     c_locale = (locale_t) 0;
     crypt_set_log_callback (NULL, NULL, NULL);
+    crypt_set_debug_level (CRYPT_DEBUG_NONE);
 }
 
 /**
@@ -1033,8 +1037,13 @@ static gboolean luks_open (const gchar *device, const gchar *name, const guint8
     g_free (key_buffer);
 
     if (ret < 0) {
-        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
-                     "Failed to activate device: %s", strerror_l(-ret, c_locale));
+        if (ret == -EPERM)
+          g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                       "Failed to activate device: Incorrect passphrase.");
+        else
+          g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                       "Failed to activate device: %s", strerror_l(-ret, c_locale));
+
         crypt_free (cd);
         bd_utils_report_finished (progress_id, (*error)->message);
         return FALSE;
@@ -1444,6 +1453,7 @@ gboolean bd_crypto_luks_change_key (const gchar *device, const gchar *pass, cons
 
 static gboolean luks_resize (const gchar *luks_device, guint64 size, const guint8 *pass_data, gsize data_len, const gchar *key_file, GError **error) {
     struct crypt_device *cd = NULL;
+    struct crypt_active_device cad;
     gint ret = 0;
     guint64 progress_id = 0;
     gchar *msg = NULL;
@@ -1463,6 +1473,16 @@ static gboolean luks_resize (const gchar *luks_device, guint64 size, const guint
         return FALSE;
     }
 
+    ret = crypt_get_active_device (cd, luks_device, &cad);
+    if (ret != 0) {
+        g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                     "Failed to get information about '%s': %s",
+                     luks_device, strerror_l(-ret, c_locale));
+        crypt_free (cd);
+        bd_utils_report_finished (progress_id, (*error)->message);
+        return FALSE;
+    }
+
     if (pass_data || key_file) {
         if (key_file) {
             success = g_file_get_contents (key_file, &key_buffer, &buf_len, error);
@@ -1478,7 +1498,7 @@ static gboolean luks_resize (const gchar *luks_device, guint64 size, const guint
 #ifdef LIBCRYPTSETUP_2
         ret = crypt_activate_by_passphrase (cd, NULL, CRYPT_ANY_SLOT,
                                             key_buffer ? key_buffer : (char*) pass_data,
-                                            buf_len, CRYPT_ACTIVATE_KEYRING_KEY);
+                                            buf_len, cad.flags & CRYPT_ACTIVATE_KEYRING_KEY);
 #else
         ret = crypt_activate_by_passphrase (cd, NULL, CRYPT_ANY_SLOT,
                                             key_buffer ? key_buffer : (char*) pass_data,
@@ -1487,8 +1507,12 @@ static gboolean luks_resize (const gchar *luks_device, guint64 size, const guint
         g_free (key_buffer);
 
         if (ret < 0) {
-            g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
-                         "Failed to activate device: %s", strerror_l(-ret, c_locale));
+            if (ret == -EPERM)
+              g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                           "Failed to activate device: Incorrect passphrase.");
+            else
+              g_set_error (error, BD_CRYPTO_ERROR, BD_CRYPTO_ERROR_DEVICE,
+                           "Failed to activate device: %s", strerror_l(-ret, c_locale));
             crypt_free (cd);
             bd_utils_report_finished (progress_id, (*error)->message);
             return FALSE;
